#!/bin/bash
#
#SBATCH --share
#SBATCH --get-user-env 
#SBATCH --job-name=job_1
#SBATCH --output=/home/guests/jir2004/perlmodule/Runner-Init/dev/testserial/slurm_logs_2015_01_12T05_42_24.log/job_1.log

#SBATCH --partition=hpc


#SBATCH --nodelist=hpc005

#SBATCH --cpus-per-task=4




cd /data/home/jir2004/perlmodule/Runner-Init/dev
mcerunner.pl --procs 1 --infile /home/guests/jir2004/perlmodule/Runner-Init/dev/testserial/job_1.in --outdir /home/guests/jir2004/perlmodule/Runner-Init/dev/testserial --logname job_1
